@@ -109,6 +109,18 @@
 #define FWTS_PCI_CONFIG_TYPE2_SUBSYSTEM_VENDOR_ID	(0x42)
 #define FWTS_PCI_CONFIG_TYPE2_LEGACY_MODE_BASE_ADDRESS	(0x44)
 
+/* PCI config device port type */
+#define FWTS_PCI_EXP_FLAGS_TYPE				0x00f0
+#define  FWTS_PCI_EXP_TYPE_ENDPOINT			(0x0)
+#define  FWTS_PCI_EXP_TYPE_LEGACY_ENDPOINT		(0x1)
+#define  FWTS_PCI_EXP_TYPE_ROOT_PORT			(0x4)
+#define  FWTS_PCI_EXP_TYPE_UPSTREAM_PORT		(0x5)
+#define  FWTS_PCI_EXP_TYPE_DOWNSTREAM_PORT		(0x6)
+#define  FWTS_PCI_EXP_TYPE_PCI_BRIDGE			(0x7)
+#define  FWTS_PCI_EXP_TYPE_PCIE_BRIDGE			(0x8)
+#define  FWTS_PCI_EXP_TYPE_RC_ENDPOINT			(0x9)
+#define  FWTS_PCI_EXP_TYPE_RC_EVENT_COLLECTOR		(0xa)
+
 /* PCI config header types */
 #define FWTS_PCI_CONFIG_HEADER_TYPE_NON_BRIDGE		(0x00)
 #define FWTS_PCI_CONFIG_HEADER_TYPE_PCI_BRIDGE		(0x01)
