@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2023 Canonical
+ * Copyright (C) 2010-2024 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -50,7 +50,7 @@
 
 #define ACPI_MAX_INIT_TABLES		(64)	/* Number of ACPI tables */
 
-#define MAX_SEMAPHORES			(1024)	/* For semaphore tracking */
+#define MAX_SEMAPHORES			(2048)	/* For semaphore tracking */
 #define MAX_THREADS			(128)	/* For thread tracking */
 
 #define MAX_WAIT_TIMEOUT		(20)	/* Seconds */
@@ -262,7 +262,6 @@ static ACPI_STATUS fwts_region_handler(
 	UINT8                   *buffer = ACPI_CAST_PTR(UINT8, value);
 	ACPI_SIZE               length;
 	UINT32                  bytewidth;
-	ACPI_CONNECTION_INFO    *context;
 	int			i;
 
 	if (!regionobject)
@@ -274,8 +273,6 @@ static ACPI_STATUS fwts_region_handler(
 
 	fwts_acpi_region_handler_called_set(true);
 
-	context = ACPI_CAST_PTR (ACPI_CONNECTION_INFO, handlercontext);
-
 	switch (regionobject->Region.SpaceId) {
 	case ACPI_ADR_SPACE_SYSTEM_IO:
 		switch (function & ACPI_IO_MASK) {
